# cancel_historical_data { #shinybroker.cancel_historical_data }

```python
cancel_historical_data(reqId)
```

Create a message that will cancel an existing historical data request.

## Parameters {.doc-section .doc-section-parameters}

| Name   | Type         | Description                                                         | Default    |
|--------|--------------|---------------------------------------------------------------------|------------|
| reqId  | [int](`int`) | The numerical ID of the historical data request you want to cancel. | _required_ |

## Examples {.doc-section .doc-section-examples}

```
import shinybroker as sb
# Message that will cancel historical data request having ID of 1
cancel_historical_data_msg = sb.cancel_historical_data(1)
print(cancel_historical_data_msg)
```